==> xlnl-3.1.7.tar.gz: xlnl-3.1.7/src/main-x.c <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: main-x.c,v 1.7 2007/02/23 05:30:28 bowkenken Exp $
***************************************************************/

/***************************************************************
* X-Window ѤΥᥤ
***************************************************************/

#define	MAIN_X_C
#include	"inc.h"

/***************************************************************
* ᥤ󡦥롼
* int argc : ο
* char **argv : Υꥹ
* return : λ
***************************************************************/

int	main_ws( int argc, char **argv )
{
	init_arg();

	g_flg_gui = TRUE;

#if	defined( NDEBUG )
	g_flg_cui = FALSE;
#elif	defined( DEBUG )
	g_flg_cui = TRUE;
#else
	g_flg_cui = FALSE;
#endif

	chk_arg( argc, argv );
	init_game();

	if( !call_game_thread_create( main_thread ) )
		return EXIT_FAILURE;

	return EXIT_SUCCESS;
}

/***************************************************************
* ᥤ󡦥å
* void *p : 
* return : 
***************************************************************/

void	*main_thread( void *p )
{
	game_main();

	return NULL;
}

==> xlnl-3.3.0.tar.gz: xlnl-3.3.0/src/main-x.c <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: main-x.c,v 1.9 2007/12/14 23:24:41 bowkenken Exp $
***************************************************************/

/***************************************************************
* X-Window ѤΥᥤ
***************************************************************/

#define	MAIN_X_C
#include	"inc.h"

void	*(*g_main_thread_ptr)( void * );

/***************************************************************
* ᥤ󡦥롼
* int argc : ο
* char **argv : Υꥹ
* return : λ
***************************************************************/

int	main_ws( int argc, char **argv )
{
	g_main_thread_ptr = NULL;

	init_arg();

	g_flg_gui = TRUE;

#if	defined( NDEBUG )
	g_flg_cui = FALSE;
#elif	defined( DEBUG )
	g_flg_cui = TRUE;
#else
	g_flg_cui = FALSE;
#endif

	chk_arg( argc, argv );
	init_game();

	if( !call_game_thread_create( main_thread ) )
		return EXIT_FAILURE;

	return EXIT_SUCCESS;
}

/***************************************************************
* λ
* long code : λ
***************************************************************/

void	gexit( long code )
{
#ifdef	D_GTK
	gtk_exit( code );
#else	/* D_GTK */
	exit( code );
#endif	/* D_GTK */
}

/***************************************************************
* ᥤ󡦥å
* void *p : 
* return : 
***************************************************************/

void	*main_thread( void *p )
{
	g_main_thread_ptr = main_thread;

	game_main();

	return NULL;
}
